Code generation library for Winch.
Re-exports
pub use isa::*;
Modules
Macros
- bail
- Early exit from the current function with an error.
- ensure
- Ensure that a condition holds true, or else early exit from the current function with an error.
- format_
err - Construct an
Errorvia string formatting or another error.
Structs
- Builtin
Functions - Provides the ABI signatures for each builtin function signature.
- Error
- Wasmtime’s universal error type.
- FuncEnv
- The function environment.
Traits
- Context
- Extension trait to add error context to results.
Type Aliases
- Result
- A result of either
Ok(T)or anErr(Error).